function varargout = selectDirectory_gui(varargin)
% Select a directory to place the files to be extracted
%-------------------------------------------------------------------------
%   Copyright (C) 2009
%   Neuroimage Computing Group, State Key Laboratory of
%   Cognitive Neuroscience and Learning, Beijing normal University
%	Written by Guiwen Chen
%	Version=1.0;
%	Release=20091010;
%------------------------------------------------------------------------
%
% SELECTDIRECTORY_GUI M-file for selectDirectory_gui.fig
%      SELECTDIRECTORY_GUI, by itself, creates a new SELECTDIRECTORY_GUI or raises the existing
%      singleton*.
%
%      H = SELECTDIRECTORY_GUI returns the handle to a new SELECTDIRECTORY_GUI or the handle to
%      the existing singleton*.
%
%      SELECTDIRECTORY_GUI('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in SELECTDIRECTORY_GUI.M with the given input arguments.
%
%      SELECTDIRECTORY_GUI('Property','Value',...) creates a new SELECTDIRECTORY_GUI or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before selectDirectory_gui_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to selectDirectory_gui_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help selectDirectory_gui

% Last Modified by GUIDE v2.5 10-Oct-2009 22:05:04

% Begin initialization code - DO NOT EDIT

gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @selectDirectory_gui_OpeningFcn, ...
                   'gui_OutputFcn',  @selectDirectory_gui_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before selectDirectory_gui is made visible.
function selectDirectory_gui_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to selectDirectory_gui (see VARARGIN)

% Choose default command line output for selectDirectory_gui
handles.output = hObject;
handles.cfg.outDir='';
global cfg;
cfg=handles.cfg;
if(length(varargin)>1)
Aoption=varargin{1};
switch lower(Aoption),
    case 'initdir',        
%         set(handles.HdlDir,'String',fullfile(varargin{2},'output'));
%         return;        
    otherwise,
end
end

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes selectDirectory_gui wait for user response (see UIRESUME)
uiwait(handles.FigSelectDir);

if(ishandle(handles.output))
    delete(handles.output);
end

% --- Outputs from this function are returned to the command line.
function varargout = selectDirectory_gui_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
if(isfield(handles,'cfg'))
    varargout{1} = handles.cfg;
else
    global cfg;
    varargout{1} = cfg;
    clear global cfg;
end


function HdlDir_Callback(hObject, eventdata, handles)
% hObject    handle to HdlDir (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of HdlDir as text
%        str2double(get(hObject,'String')) returns contents of HdlDir as a double


% --- Executes during object creation, after setting all properties.
function HdlDir_CreateFcn(hObject, eventdata, handles)
% hObject    handle to HdlDir (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in HdlSelectDir.
function HdlSelectDir_Callback(hObject, eventdata, handles)
% hObject    handle to HdlSelectDir (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
theDir=pwd;
theDir =uigetdir(theDir, 'Please select a file directory to output all the data: ');


if ischar(theDir),
    set(handles.HdlDir,'String',theDir);
    handles.moicaCfg.outDir=theDir;
end


% --- Executes on button press in HdlButOK.
function HdlButOK_Callback(hObject, eventdata, handles)
% hObject    handle to HdlButOK (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


handles.cfg.outDir=get(handles.HdlDir,'String');
if(isempty(handles.cfg.outDir))
    warndlg('Please select the directory');
    return;
end
handles.cfg.execute=1;
guidata(hObject,handles);
global cfg;
cfg=handles.cfg;
uiresume(handles.FigSelectDir);
if(ishandle(handles.output))
    delete(handles.output);
end

% --- Executes on button press in HdlButCancel.
function HdlButCancel_Callback(hObject, eventdata, handles)
% hObject    handle to HdlButCancel (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
handles.cfg.execute=0;
guidata(hObject,handles);
uiresume(handles.FigSelectDir);
if(ishandle(handles.output))
    delete(handles.output);
end

